//
// File: mYatzee.cc
// main loops
//
// Created by: Joni Valtanen <jvaltane@lpt.fi>
// Created on: Sat Oct 30 22:01:01 2004
//

#include "mYatzee.h"


mYatzee::mYatzee()
{
	mfile = new file();
	msdl = new mSDL(mfile);
	
	string theme = "/default";

#ifndef WIN32	
	string datadir = DATADIR + theme;
#else
	string datadir = DATADIR_WIN32 + theme;
#endif

	pn_main = datadir + PIC_MAINMENU;
	pn_game = datadir + PIC_GAME;
	pn_config = datadir + PIC_CONFIG;

}


mYatzee::~mYatzee()
{
	delete msdl;
	delete mfile;
}

//starts engine
int mYatzee::startEngine()
{
#ifdef DEBUG
	cout << "startEngine" << endl;
#endif
//	int i;
	int handle = 0;
	bool quit=false;
	
	mfile->checkConfig();
#ifdef DEBUG
	cout << "checkconf aft" << endl;
#endif

	mfile->readConfig();
//	mfile->createHiscoreFile(); // not nessessary
#ifdef DEBUG
	cout << "readcconf aft" << endl;
#endif
	mfile->readHiscores();
#ifdef DEBUG
	cout << "readHiscores aft" << endl;
#endif
	yGame = mfile->getGame();
#ifdef DEBUG
	cout << "getgame aft" << endl;
#endif
	yHiscore = mfile->getHiscore();
	
	if( !msdl->initScreen(yGame) )
		return 0;

	while(!quit)
	{
		if( !msdl->drawScreen(pn_main.c_str()) )
		{
			return 0;	
		}
		
		if( ( handle = msdl->handleMainmenu() ) < 1 )
		{
			return 0;	
		}
		switch( handle )
		{
		case QUIT:
		case WQUIT: // quit
			quit = true;	
			break;
		case START:  //start
			startGame();
			break;
		case CONFIG:  //Configure game
			if(configGame() == QUICKQUIT)
				return 2;
			break;
		default:
			break;
		}
			
	}
	if(!msdl->closeScreen())
		return 0;

	return 1;	
}

//gamescreen
int mYatzee::startGame()
{
	int handle = 0;
	bool gameQuit=false;
	yGame->setTotalPlayers();
	while(!gameQuit)
	{
		if( !msdl->drawScreen(pn_game.c_str()) )
		{
			msdl->closeScreen();
			return 0;
		}
		if( ( handle = msdl->handleGameScreen()) < 1 )
		{
			msdl->closeScreen();
			return 0;
		}
	
		switch(handle)
		{
			case QUIT:
			case END:
				gameQuit=true;
				break;
			case WQUIT:
				//window closebutton
				gameQuit = true;
				break;
			default:
				break;
		}			
	}

	mfile->writeHiscores();
	return 1;	
}

// configscreen
int mYatzee::configGame()
{
	int handle = 0;
	bool configQuit=false;
	bool yfs = yGame->getFullscreen();
	
	while(!configQuit)
	{
		if( !msdl->drawScreen(pn_config.c_str()) )
		{
			msdl->closeScreen();
			return 0;
		}
		
		if( ( handle = msdl->handleConfigScreen()) < 1 )
		{
			msdl->closeScreen();
			return 0;
		}
	
		switch(handle)
		{
			case WQUIT:
				//window closebutton
				configQuit = true;
				break;
			case QUIT:
				configQuit = true;
				break;
			case OK:
				configQuit = true;
				//sets fullscreen on the fly
				if(yGame->getFullscreen() != yfs)
				{
					if(!msdl->closeScreen())
						return QUICKQUIT;
					delete msdl;
					msdl = new mSDL(mfile);
					if(!msdl->initScreen(yGame))
						return QUICKQUIT;
				}
				mfile->writeConfig();
				break;
			default:
				break;
		}			
	}		
	return 1;	
}
